.. _api:

====
API
====

.. toctree::
   :maxdepth: 2

   generator/index
   analysis/index
   GUI/index

Discovery
---------
You can use our built to discover our package

.. automodule:: phasor_noise
   :members: